@@ -109,6 +109,40 @@ impl ToSVG for Shape {
                 }
             )),
             ShapeType::Drawing(shapes) => shapes.to_svg(),
+            ShapeType::Path { keypoints, closed } => {
+                let start = keypoints.first().ok_or("No start")?;
+                let rest = &keypoints[1..];
+
+                Ok(format!(
+                    r#"<path d="{start} {rest} {close}" {style}/>"#,
+                    style = self.style.to_svg()?,
+                    start = if let Keypoint::Point(start) = start {
+                        format!("M {} {} ", start.x, start.y)
+                    } else {
+                        unreachable!();
+                    },
+                    rest = rest
+                        .iter()
+                        .map(|v| match v {
+                            Keypoint::Point(p) => format!("L {} {} ", p.x, p.y),
+                            Keypoint::Bezier {
+                                destination,
+                                start_prop,
+                                dest_prop,
+                            } => format!(
+                                "C {} {} {} {} {} {} ",
+                                start_prop.x,
+                                start_prop.y,
+                                dest_prop.x,
+                                dest_prop.y,
+                                destination.x,
+                                destination.y,
+                            ),
+                        })
+                        .collect::<String>(),
+                    close = if *closed { "Z" } else { "" }
+                ))
+            }
         }
     }
 }
@@ -187,11 +221,11 @@ impl ToSVG for FontWeight {
 
 impl ToSVG for Color {
     fn to_svg(&self) -> Result<String, Box<dyn Error>> {
-        match self {
-            Color::RGB { r, g, b } => {
-                Color::U32((*r as u32) << 16 | (*g as u32) << 8 | *b as u32).to_svg()
-            }
-            Color::U32(c) => Ok(format!("#{}", format!("{:#08X?}", c).split_at(2).1)),
+        let c = self.rgba();
+        if let Color::RGBA { r, g, b, a } = c {
+            Ok(format!("rgba({},{},{},{})", r, g, b, a))
+        } else {
+            unreachable!()
         }
     }
 }
@@ -220,7 +254,7 @@ mod tests {
                 .with_align(TextAlign::Center),
         );
 
-        let text_svg = r#"<text x="10" y="10" text-anchor="middle" font-size="10" font-weight="bold" fill='#FF0000' >hello world</text>"#;
+        let text_svg = r#"<text x="10" y="10" text-anchor="middle" font-size="10" font-weight="bold" fill='#FF0000FF' >hello world</text>"#;
         let drawing_svg = format!(
             r#"<svg width="0px" height="0px" viewBox="-0 -0 0 0">{}</svg>"#,
             text_svg
